
The `cardinal` module holds the definition of the `Direction` classes.

The `Direction` classes enables two important features that create a more user friendly way of working with relative x and y positional offsets.

1.) Specify an absolute direction (as defined by x and y axix modifiers under the hood) in a human readable, eg `right`or `up`,

2.) Lets us extend the offset for cell to cell navigation, eg: `right(3)` denotes "3 cells to the right".